==> lxqt-panel_0.17.1.orig.tar.xz: lxqt-panel-0.17.1/plugin-kbindicator/translations/kbindicator_ar.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ar">
<context>
    <name>Content</name>
    <message>
        <location filename="../src/content.cpp" line="46"/>
        <source>C</source>
        <comment>Label for CapsLock indicator</comment>
        <translation>C</translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="49"/>
        <source>CapsLock</source>
        <comment>Tooltip for CapsLock indicator</comment>
        <translation>قافل الحالة</translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="53"/>
        <source>N</source>
        <comment>Label for NumLock indicator</comment>
        <translation>N</translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="55"/>
        <source>NumLock</source>
        <comment>Tooltip for NumLock indicator</comment>
        <translation>قافل الأرقام</translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="60"/>
        <source>S</source>
        <comment>Label for ScrollLock indicator</comment>
        <translation>S</translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="62"/>
        <source>ScrollLock</source>
        <comment>Tooltip for ScrollLock indicator</comment>
        <translation>قافل التمرير</translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="104"/>
        <source>Layout</source>
        <translation>التخطيط</translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="104"/>
        <source>Variant</source>
        <translation>التنويعة</translation>
    </message>
</context>
<context>
    <name>KbdStateConfig</name>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="14"/>
        <source>Keyboard state settings</source>
        <translation>إعدادات حالة لوحة المفاتيح</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="20"/>
        <source>Lock Indicators</source>
        <translation>مؤشّرات القفل</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="26"/>
        <source>Show Caps Lock</source>
        <translation>اعرض قافل الحالة</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="33"/>
        <source>Show Num Lock</source>
        <translation>اعرض قافل الأرقام</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="40"/>
        <source>Show Scroll Lock</source>
        <translation>اعرض قافل التمرير</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="50"/>
        <source>Keyboard Layout Indicator</source>
        <translation>مؤشّر تخطيط لوحة المفاتيح</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="62"/>
        <source>Switching policy</source>
        <translation>سياسة التبديل</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="99"/>
        <source>Flags path pattern:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="106"/>
        <source>File path pattern for country flags. Must contain &lt;strong&gt;%1&lt;/strong&gt; which is replaced by the two letter ISO country code (lower case).&lt;br&gt;&lt;br&gt;Example: /usr/share/iso-flags-svg/country-squared/%1.svg</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="116"/>
        <source>Configure layouts</source>
        <translation>اضبط التخطيطات</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="69"/>
        <source>Global</source>
        <translation>عمومي</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="79"/>
        <source>Window</source>
        <translation>حسب النافذة</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="89"/>
        <source>Application</source>
        <translation>حسب التطبيق</translation>
    </message>
</context>
</TS>

==> lxqt-panel_1.2.1.orig.tar.xz: lxqt-panel-1.2.1/plugin-kbindicator/translations/kbindicator_ar.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ar">
<context>
    <name>Content</name>
    <message>
        <location filename="../src/content.cpp" line="46"/>
        <source>C</source>
        <comment>Label for CapsLock indicator</comment>
        <translation>C</translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="49"/>
        <source>CapsLock</source>
        <comment>Tooltip for CapsLock indicator</comment>
        <translation>قافل الحالة</translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="53"/>
        <source>N</source>
        <comment>Label for NumLock indicator</comment>
        <translation>N</translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="55"/>
        <source>NumLock</source>
        <comment>Tooltip for NumLock indicator</comment>
        <translation>قافل الأرقام</translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="60"/>
        <source>S</source>
        <comment>Label for ScrollLock indicator</comment>
        <translation>S</translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="62"/>
        <source>ScrollLock</source>
        <comment>Tooltip for ScrollLock indicator</comment>
        <translation>قافل التمرير</translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="104"/>
        <source>Layout</source>
        <translation>التخطيط</translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="104"/>
        <source>Variant</source>
        <translation>التنويعة</translation>
    </message>
</context>
<context>
    <name>KbdStateConfig</name>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="14"/>
        <source>Keyboard state settings</source>
        <translation>إعدادات حالة لوحة المفاتيح</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="20"/>
        <source>Lock Indicators</source>
        <translation>مؤشّرات القفل</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="26"/>
        <source>Show Caps Lock</source>
        <translation>اعرض قافل الحالة</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="33"/>
        <source>Show Num Lock</source>
        <translation>اعرض قافل الأرقام</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="40"/>
        <source>Show Scroll Lock</source>
        <translation>اعرض قافل التمرير</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="50"/>
        <source>Keyboard Layout Indicator</source>
        <translation>مؤشّر تخطيط لوحة المفاتيح</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="62"/>
        <source>Switching policy</source>
        <translation>سياسة التبديل</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="99"/>
        <source>Flags path pattern:</source>
        <translation>نمط مسار الإشارات:</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="106"/>
        <source>File path pattern for country flags. Must contain &lt;strong&gt;%1&lt;/strong&gt; which is replaced by the two letter ISO country code (lower case).&lt;br&gt;&lt;br&gt;Example: /usr/share/iso-flags-svg/country-squared/%1.svg</source>
        <translation>نمط مسار الملف لأعلام الدول. يجب أن تحتوي على &lt;strong&gt;%1&lt;/strong&gt; الذي يتم استبداله برمز الدولة ISO المكون من حرفين (الأحرف الصغيرة).&lt;br&gt;&lt;br&gt;مثال: /usr/share/iso-flags-svg/country-squared/%1.svg</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="116"/>
        <source>Configure layouts</source>
        <translation>اضبط التخطيطات</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="69"/>
        <source>Global</source>
        <translation>عمومي</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="79"/>
        <source>Window</source>
        <translation>حسب النافذة</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="89"/>
        <source>Application</source>
        <translation>حسب التطبيق</translation>
    </message>
</context>
</TS>
